mcqd: An exact algorithm for finding a maximum clique in an undirected graph
============================================================================

Description
-----------

MaxCliqueDyn is a fast exact algorithm for finding a maximum clique in
an undirected graph.

License
-------

GPL 3


Upstream Contact
----------------

MCQD is currently being maintained by Janez Konc.
https://gitlab.com/janezkonc/mcqd

